@@ -155,15 +155,17 @@ def __read_hubspot(settings: dict):
 
 
 def read_fb_ads(my_app_id, my_app_secret, my_access_token,
-                date_preset = "today",
-               account_name = {'Numbers' : 'act_113103090066338',
-                'Linkers' : 'act_203938767415072',
-                'WinWay' : 'act_2591302164494270',
-                'Miss Tariffa Agency' : 'act_280378753012689',
-                'Humable' : 'act_284748836042514',
-                'Miss Tariffa' : 'act_503932150489858',
-                'We are Fiber' : 'act_638714426864395'
-               }):
+                
+                date_preset = "last_7d",
+                
+                account_name = {'Numbers' : 'act_113103090066338',
+                                'Linkers' : 'act_203938767415072',
+                                'WinWay' : 'act_2591302164494270',
+                                'Miss Tariffa Agency' : 'act_280378753012689',
+                                'Humable' : 'act_284748836042514',
+                                'Miss Tariffa' : 'act_503932150489858',
+                                'We are Fiber' : 'act_638714426864395'
+                                }):
     
     from askdata.integrations import facebook_api
     
@@ -173,4 +175,32 @@ def read_fb_ads(my_app_id, my_app_secret, my_access_token,
 
 
 
+##################################
+########## GOOGLE ADS ############
+##################################
 
+
+def read_google_ads(n_range = 7, 
+                   
+                  admin_account = {'Be You': '291-824-5921'
+                                 ,'Humable': '760-045-3647'
+                                 ,'Linkers': '504-714-3560'
+                                 ,'Miss Tariffa': '605-298-4997'
+                                 ,'Miss Tariffa Agency': '427-886-1215'
+                                 ,'Numbers': '794-577-9076'
+                                 ,'Wearefiber': '778-681-5313'
+                                },
+                   
+                   yaml_file_path = 'googleads.yaml'):
+    
+    
+    from askdata.integrations import google_api
+    
+    google_ads = google_api.get_google_ads(n_range, admin_account, yaml_file_path)
+    
+    return google_ads
+    
+    
+    
+    
+    
\ No newline at end of file
